# quina

[![Build Status](https://travis-ci.com/KD-Group/quina.svg?branch=master)](https://travis-ci.com/KD-Group/quina)
[![Build status](https://ci.appveyor.com/api/projects/status/rxaako34wqkqh5gl/branch/master?svg=true)](https://ci.appveyor.com/project/SF-Zhou/quina/branch/master)
[![codecov](https://codecov.io/gh/KD-Group/quina/branch/master/graph/badge.svg)](https://codecov.io/gh/KD-Group/quina)

PySide2 MVVM Framework
